@@ -173,7 +173,7 @@ unsigned int Kleo::classify(const QStringList &fileNames)
         return 0;
     }
     unsigned int result = classify(fileNames.front());
-    Q_FOREACH (const QString &fileName, fileNames) {
+    for (const QString &fileName : fileNames) {
         result &= classify(fileName);
     }
     return result;
@@ -397,7 +397,7 @@ const char *Kleo::outputFileExtension(unsigned int classification, bool usePGPFi
         if ((classifications[i].classification & classification) == classification) {
             return classifications[i].extension;
         }
-    return 0;
+    return nullptr;
 }
 
 bool Kleo::isFingerprint(const QString &fpr)
